@@ -102,12 +102,14 @@
 
 #define IGNORE_VIRTUAL_DEVICES	FALSE
 #define ACCEPT_VIRTUAL_DEVICES	TRUE
+#define LOCAL_TIME		FALSE
 
 /* Environment variables */
 #define ENV_TIME_FMT		"S_TIME_FORMAT"
 #define ENV_TIME_DEFTM		"S_TIME_DEF_TIME"
 #define ENV_COLORS		"S_COLORS"
 #define ENV_COLORS_SGR		"S_COLORS_SGR"
+#define ENV_REPEAT_HEADER	"S_REPEAT_HEADER"
 
 #define C_NEVER			"never"
 #define C_ALWAYS		"always"
@@ -240,8 +242,8 @@ void get_HZ
 	(void);
 void get_kb_shift
 	(void);
-time_t get_localtime
-	(struct tm *, int);
+time_t get_xtime
+	(struct tm *, int, int);
 time_t get_time
 	(struct tm *, int);
 void init_nls
