@@ -1,6 +1,7 @@
 /*
  * mpstat: per-processor statistics
  * (C) 2000-2022 by Sebastien GODARD (sysstat <at> orange.fr)
+ * Copyright (C) 2022 Oracle and/or its affiliates.
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -49,25 +50,25 @@ char *sccsid(void) { return (SCCSID); }
 unsigned long long uptime_cs[3] = {0, 0, 0};
 
 /* NOTE: Use array of _char_ for bitmaps to avoid endianness problems...*/
-unsigned char *cpu_bitmap;	/* Bit 0: Global; Bit 1: 1st proc; etc. */
-unsigned char *node_bitmap;	/* Bit 0: Global; Bit 1: 1st NUMA node; etc. */
+unsigned char *cpu_bitmap = NULL;	/* Bit 0: Global; Bit 1: 1st proc; etc. */
+unsigned char *node_bitmap = NULL;	/* Bit 0: Global; Bit 1: 1st NUMA node; etc. */
 
 /* Structures used to save CPU and NUMA nodes CPU stats */
-struct stats_cpu *st_cpu[3];
-struct stats_cpu *st_node[3];
+struct stats_cpu *st_cpu[3] = {NULL, NULL, NULL};
+struct stats_cpu *st_node[3] = {NULL, NULL, NULL};
 
 /*
  * Structure used to save total number of interrupts received
  * among all CPU and for each CPU.
  */
-struct stats_global_irq *st_irq[3];
+struct stats_global_irq *st_irq[3] = {NULL, NULL, NULL};
 
 /*
  * Structures used to save, for each interrupt, the number
  * received by each CPU.
  */
-struct stats_irqcpu *st_irqcpu[3];
-struct stats_irqcpu *st_softirqcpu[3];
+struct stats_irqcpu *st_irqcpu[3] = {NULL, NULL, NULL};
+struct stats_irqcpu *st_softirqcpu[3] = {NULL, NULL, NULL};
 
 /*
  * Number of CPU per node, e.g.:
@@ -75,16 +76,16 @@ struct stats_irqcpu *st_softirqcpu[3];
  * cpu_per_node[1]: nr of CPU for node 0
  * etc.
  */
-int *cpu_per_node;
+int *cpu_per_node = NULL;
 
 /*
  * Node number the CPU belongs to, e.g.:
  * cpu2node[0]: node nr for CPU 0
  */
-int *cpu2node;
+int *cpu2node = NULL;
 
 /* CPU topology */
-struct cpu_topology *st_cpu_topology;
+struct cpu_topology *st_cpu_topology = NULL;
 
 struct tm mp_tstamp[3];
 
@@ -134,7 +135,7 @@ void usage(char *progname)
 		progname);
 
 	fprintf(stderr, _("Options are:\n"
-			  "[ -A ] [ -n ] [ -T ] [ -u ] [ -V ]\n"
+			  "[ -A ] [ -H ] [ -n ] [ -T ] [ -u ] [ -V ]\n"
 			  "[ -I { SUM | CPU | SCPU | ALL } ] [ -N { <node_list> | ALL } ]\n"
 			  "[ --dec={ 0 | 1 | 2 } ] [ -o JSON ] [ -P { <cpu_list> | ALL } ]\n"));
 	exit(1);
@@ -175,76 +176,88 @@ void int_handler(int sig)
  * IN:
  * @nr_cpus	Number of CPUs. This is the real number of available CPUs + 1
  * 		because we also have to allocate a structure for CPU 'all'.
+ * @pos		Indicate which structures should be initialized. When @pos is
+ *		non zero, it means that only the additional, newly allocated
+ *		structures should be initialized.
  ***************************************************************************
  */
-void salloc_mp_struct(int nr_cpus)
+void salloc_mp_struct(int nr_cpus, int pos)
 {
 	int i;
 
 	for (i = 0; i < 3; i++) {
 
-		if ((st_cpu[i] = (struct stats_cpu *) malloc(STATS_CPU_SIZE * nr_cpus))
+		if ((st_cpu[i] = (struct stats_cpu *) realloc(st_cpu[i], STATS_CPU_SIZE * nr_cpus))
 		    == NULL) {
-			perror("malloc");
+			perror("realloc");
 			exit(4);
 		}
-		memset(st_cpu[i], 0, STATS_CPU_SIZE * nr_cpus);
 
-		if ((st_node[i] = (struct stats_cpu *) malloc(STATS_CPU_SIZE * nr_cpus))
+		if ((st_node[i] = (struct stats_cpu *) realloc(st_node[i], STATS_CPU_SIZE * nr_cpus))
 		    == NULL) {
-			perror("malloc");
+			perror("realloc");
 			exit(4);
 		}
-		memset(st_node[i], 0, STATS_CPU_SIZE * nr_cpus);
 
-		if ((st_irq[i] = (struct stats_global_irq *) malloc(STATS_GLOBAL_IRQ_SIZE * nr_cpus))
+		if ((st_irq[i] = (struct stats_global_irq *) realloc(st_irq[i],
+								     STATS_GLOBAL_IRQ_SIZE * nr_cpus))
 		    == NULL) {
-			perror("malloc");
+			perror("realloc");
 			exit(4);
 		}
-		memset(st_irq[i], 0, STATS_GLOBAL_IRQ_SIZE * nr_cpus);
 
-		if ((st_irqcpu[i] = (struct stats_irqcpu *) malloc(STATS_IRQCPU_SIZE * nr_cpus * irqcpu_nr))
+		if ((st_irqcpu[i] = (struct stats_irqcpu *) realloc(st_irqcpu[i],
+								    STATS_IRQCPU_SIZE * nr_cpus * irqcpu_nr))
 		    == NULL) {
-			perror("malloc");
+			perror("realloc");
 			exit(4);
 		}
-		memset(st_irqcpu[i], 0, STATS_IRQCPU_SIZE * nr_cpus * irqcpu_nr);
 
-		if ((st_softirqcpu[i] = (struct stats_irqcpu *) malloc(STATS_IRQCPU_SIZE * nr_cpus * softirqcpu_nr))
+		if ((st_softirqcpu[i] = (struct stats_irqcpu *) realloc(st_softirqcpu[i],
+									STATS_IRQCPU_SIZE * nr_cpus * softirqcpu_nr))
 		     == NULL) {
-			perror("malloc");
+			perror("realloc");
 			exit(4);
 		}
-		memset(st_softirqcpu[i], 0, STATS_IRQCPU_SIZE * nr_cpus * softirqcpu_nr);
 	}
 
-	if ((cpu_bitmap = (unsigned char *) malloc((nr_cpus >> 3) + 1)) == NULL) {
-		perror("malloc");
-		exit(4);
-	}
-	memset(cpu_bitmap, 0, (nr_cpus >> 3) + 1);
-
-	if ((node_bitmap = (unsigned char *) malloc((nr_cpus >> 3) + 1)) == NULL) {
-		perror("malloc");
-		exit(4);
-	}
-	memset(node_bitmap, 0, (nr_cpus >> 3) + 1);
-
-	if ((cpu_per_node = (int *) malloc(sizeof(int) * nr_cpus)) == NULL) {
-		perror("malloc");
+	if ((cpu_bitmap = (unsigned char *) realloc(cpu_bitmap, (nr_cpus >> 3) + 1)) == NULL) {
+		perror("realloc");
 		exit(4);
 	}
 
-	if ((cpu2node = (int *) malloc(sizeof(int) * nr_cpus)) == NULL) {
-		perror("malloc");
+	if ((node_bitmap = (unsigned char *) realloc(node_bitmap, (nr_cpus >> 3) + 1)) == NULL) {
+		perror("realloc");
 		exit(4);
 	}
 
-	if ((st_cpu_topology = (struct cpu_topology *) malloc(sizeof(struct cpu_topology) * nr_cpus)) == NULL) {
-		perror("malloc");
+	if ((cpu_per_node = (int *) realloc(cpu_per_node, sizeof(int) * nr_cpus)) == NULL) {
+		perror("realloc");
 		exit(4);
 	}
+
+	if ((cpu2node = (int *) realloc(cpu2node, sizeof(int) * nr_cpus)) == NULL) {
+		perror("realloc");
+		exit(4);
+	}
+
+	if ((st_cpu_topology = (struct cpu_topology *) realloc(st_cpu_topology,
+							       sizeof(struct cpu_topology) * nr_cpus)) == NULL) {
+		perror("realloc");
+		exit(4);
+	}
+
+	for (i = 0; i < 3; i++) {
+		memset(st_cpu[i] + pos, 0, STATS_CPU_SIZE * (nr_cpus - pos));
+		memset(st_node[i] + pos, 0, STATS_CPU_SIZE * (nr_cpus - pos));
+		memset(st_irq[i] + pos, 0, STATS_GLOBAL_IRQ_SIZE * (nr_cpus - pos));
+		memset(st_irqcpu[i] + pos, 0, STATS_IRQCPU_SIZE * (nr_cpus - pos) * irqcpu_nr);
+		memset(st_softirqcpu[i] + pos, 0, STATS_IRQCPU_SIZE * (nr_cpus - pos) * softirqcpu_nr);
+	}
+	if (!pos) {
+		memset(cpu_bitmap, 0, (nr_cpus >> 3) + 1);
+		memset(node_bitmap, 0, (nr_cpus >> 3) + 1);
+	}
 }
 
 /*
@@ -1956,7 +1969,7 @@ void read_interrupts_stat(char *file, struct stats_irqcpu *st_ic[], int ic_nr, i
 void rw_mpstat_loop(int dis_hdr, int rows)
 {
 	struct stats_cpu *scc;
-	int i;
+	int i, new_cpu_nr;
 	int curr = 1, dis = 1;
 	unsigned long lines = rows;
 
@@ -2069,7 +2082,7 @@ void rw_mpstat_loop(int dis_hdr, int rows)
 		memset(st_cpu[curr], 0, STATS_CPU_SIZE * (cpu_nr + 1));
 
 		/* Get time */
-		get_localtime(&(mp_tstamp[curr]), 0);
+		get_xtime(&(mp_tstamp[curr]), 0, LOCAL_TIME);
 
 		/* Read uptime and CPU stats */
 		read_uptime(&(uptime_cs[curr]));
@@ -2125,6 +2138,29 @@ void rw_mpstat_loop(int dis_hdr, int rows)
 				curr ^= 1;
 			}
 		}
+
+		if (count && USE_OPTION_H(flags)) {
+			/* Check if a vCPU has been physically hotplugged */
+			new_cpu_nr = get_cpu_nr(~0, TRUE);
+			if (new_cpu_nr > cpu_nr) {
+
+				/* Recalculate number of interrupts per processor */
+				irqcpu_nr = get_irqcpu_nr(INTERRUPTS, NR_IRQS, new_cpu_nr) +
+				NR_IRQCPU_PREALLOC;
+				/* Recalculate number of soft interrupts per processor */
+				softirqcpu_nr = get_irqcpu_nr(SOFTIRQS, NR_IRQS, new_cpu_nr) +
+				NR_IRQCPU_PREALLOC;
+
+				/* Reallocate cpu stats structures */
+				salloc_mp_struct(new_cpu_nr + 1, cpu_nr + 1);
+
+				/* Get NUMA node placement */
+				node_nr = get_node_placement(new_cpu_nr, cpu_per_node, cpu2node);
+
+				/* Update the highest processor number */
+				cpu_nr = new_cpu_nr;
+			}
+		}
 	}
 	while (count);
 
@@ -2175,7 +2211,7 @@ int main(int argc, char **argv)
 	 * cpu_nr: a value of 2 means there are 2 processors (0 and 1).
 	 * In this case, we have to allocate 3 structures: global, proc0 and proc1.
 	 */
-	salloc_mp_struct(cpu_nr + 1);
+	salloc_mp_struct(cpu_nr + 1, 0);
 
 	/* Get NUMA node placement */
 	node_nr = get_node_placement(cpu_nr, cpu_per_node, cpu2node);
@@ -2270,6 +2306,11 @@ int main(int argc, char **argv)
 					actset = TRUE;
 					break;
 
+				case 'H':
+					/* Display physically hotplugged vCPU */
+					flags |= F_OPTION_H;
+					break;
+
 				case 'n':
 					/* Display CPU stats based on NUMA node placement */
 					if (node_nr >= 0) {
@@ -2379,7 +2420,7 @@ int main(int argc, char **argv)
 	}
 
 	/* Get time */
-	get_localtime(&(mp_tstamp[0]), 0);
+	get_xtime(&(mp_tstamp[0]), 0, LOCAL_TIME);
 
 	/*
 	 * Don't buffer data if redirected to a pipe.
