@@ -39,8 +39,6 @@
 #include <pcp/import.h>
 #endif
 
-extern char *tzname[2];
-
 extern uint64_t flags;
 extern char *seps[];
 
@@ -60,32 +58,7 @@ void pcp_write_data(struct record_header *record_hdr, unsigned int flags)
 {
 #ifdef HAVE_PCP
 	int rc;
-	struct tm lrectime;
-	time_t t = record_hdr->ust_time;
 	unsigned long long utc_sec = record_hdr->ust_time;
-	static long long delta_utc = LONG_MAX;
-
-	if (!PRINT_LOCAL_TIME(flags)) {
-		if (delta_utc == LONG_MAX) {
-			/* Convert a time_t value from local time to UTC */
-			if (gmtime_r(&t, &lrectime)) {
-				utc_sec = mktime(&lrectime);
-				delta_utc = utc_sec - record_hdr->ust_time;
-			}
-		}
-		else {
-			/*
-			 * Once pmiWrite() has been called (after the first stats sample),
-			 * subsequent mktime() calls will not give the same result with
-			 * the same input data. So compute a time shift that will be used
-			 * for the next samples.
-			 * We should (really) be careful if pmiWrite() was to be used sooner
-			 * than for the first stats sample (e.g. if we want to save a
-			 * LINUX RESTART record heading the file).
-			 */
-			utc_sec += delta_utc;
-		}
-	}
 
 	/* Write data to PCP archive */
 	if ((rc = pmiWrite(utc_sec, 0)) < 0) {
@@ -102,12 +75,12 @@ void pcp_write_data(struct record_header *record_hdr, unsigned int flags)
  * IN:
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @sep		Character used as separator.
  * @file_hdr	System activity file standard header.
  ***************************************************************************
  */
-void print_dbppc_restart(char *cur_date, char *cur_time, int utc, char sep,
+void print_dbppc_restart(char *cur_date, char *cur_time, char *my_tz, char sep,
 			 struct file_header *file_hdr)
 {
 	printf("%s%c-1%c", file_hdr->sa_nodename, sep, sep);
@@ -115,8 +88,10 @@ void print_dbppc_restart(char *cur_date, char *cur_time, int utc, char sep,
 		printf("%s ", cur_date);
 	}
 	printf("%s", cur_time);
-	if (strlen(cur_date) && utc) {
-		printf(" UTC");
+	if (strlen(cur_date)) {
+		printf(" %s", PRINT_LOCAL_TIME(flags) ? my_tz
+						      : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+										: "UTC"));
 	}
 	printf("%cLINUX-RESTART\t(%d CPU)\n",
 	       sep, file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
@@ -131,18 +106,18 @@ void print_dbppc_restart(char *cur_date, char *cur_time, int utc, char sep,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  ***************************************************************************
  */
-__printf_funct_t print_db_restart(int *tab, int action, char *cur_date,
-				  char *cur_time, int utc, struct file_header *file_hdr,
+__printf_funct_t print_db_restart(int *tab, int action, char *cur_date, char *cur_time,
+				  char *my_tz, struct file_header *file_hdr,
 				  struct record_header *record_hdr)
 {
 	/* Actions F_BEGIN and F_END ignored */
 	if (action == F_MAIN) {
-		print_dbppc_restart(cur_date, cur_time, utc, ';', file_hdr);
+		print_dbppc_restart(cur_date, cur_time, my_tz, ';', file_hdr);
 	}
 }
 
@@ -155,18 +130,18 @@ __printf_funct_t print_db_restart(int *tab, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  ***************************************************************************
  */
-__printf_funct_t print_ppc_restart(int *tab, int action, char *cur_date,
-				   char *cur_time, int utc, struct file_header *file_hdr,
+__printf_funct_t print_ppc_restart(int *tab, int action, char *cur_date, char *cur_time,
+				   char *my_tz, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 	/* Actions F_BEGIN and F_END ignored */
 	if (action == F_MAIN) {
-		print_dbppc_restart(cur_date, cur_time, utc, '\t', file_hdr);
+		print_dbppc_restart(cur_date, cur_time, my_tz, '\t', file_hdr);
 	}
 }
 
@@ -179,7 +154,7 @@ __printf_funct_t print_ppc_restart(int *tab, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone (unused here).
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  *
@@ -187,16 +162,19 @@ __printf_funct_t print_ppc_restart(int *tab, int action, char *cur_date,
  * @tab		Number of tabulations.
  ***************************************************************************
  */
-__printf_funct_t print_xml_restart(int *tab, int action, char *cur_date,
-				   char *cur_time, int utc, struct file_header *file_hdr,
+__printf_funct_t print_xml_restart(int *tab, int action, char *cur_date, char *cur_time,
+				   char *my_tz, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 	if (action & F_BEGIN) {
 		xprintf((*tab)++, "<restarts>");
 	}
 	if (action & F_MAIN) {
-		xprintf(*tab, "<boot date=\"%s\" time=\"%s\" utc=\"%d\" cpu_count=\"%d\"/>",
-			cur_date, cur_time, utc ? 1 : 0,
+		xprintf(*tab, "<boot date=\"%s\" time=\"%s\" tz=\"%s\" cpu_count=\"%d\"/>",
+			cur_date, cur_time,
+			PRINT_LOCAL_TIME(flags) ? my_tz
+						: (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									  : "UTC"),
 			file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
 	}
 	if (action & F_END) {
@@ -213,7 +191,7 @@ __printf_funct_t print_xml_restart(int *tab, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone (unused here).
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  *
@@ -221,8 +199,8 @@ __printf_funct_t print_xml_restart(int *tab, int action, char *cur_date,
  * @tab		Number of tabulations.
  ***************************************************************************
  */
-__printf_funct_t print_json_restart(int *tab, int action, char *cur_date,
-				    char *cur_time, int utc, struct file_header *file_hdr,
+__printf_funct_t print_json_restart(int *tab, int action, char *cur_date, char *cur_time,
+				    char *my_tz, struct file_header *file_hdr,
 				    struct record_header *record_hdr)
 {
 	static int sep = FALSE;
@@ -236,8 +214,11 @@ __printf_funct_t print_json_restart(int *tab, int action, char *cur_date,
 			printf(",\n");
 		}
 		xprintf((*tab)++, "{");
-		xprintf(*tab, "\"boot\": {\"date\": \"%s\", \"time\": \"%s\", \"utc\": %d, \"cpu_count\": %d}",
-			cur_date, cur_time, utc ? 1 : 0,
+		xprintf(*tab, "\"boot\": {\"date\": \"%s\", \"time\": \"%s\", \"tz\": \"%s\", \"cpu_count\": %d}",
+			cur_date, cur_time,
+			PRINT_LOCAL_TIME(flags) ? my_tz
+						: (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									  : "UTC"),
 			file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
 		xprintf0(--(*tab), "}");
 		sep = TRUE;
@@ -260,20 +241,22 @@ __printf_funct_t print_json_restart(int *tab, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  ***************************************************************************
  */
-__printf_funct_t print_raw_restart(int *tab, int action, char *cur_date,
-				   char *cur_time, int utc, struct file_header *file_hdr,
+__printf_funct_t print_raw_restart(int *tab, int action, char *cur_date, char *cur_time,
+				   char *my_tz, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 	/* Actions F_BEGIN and F_END ignored */
 	if (action == F_MAIN) {
 		printf("%s", cur_time);
-		if (strlen(cur_date) && utc) {
-			printf(" UTC");
+		if (strlen(cur_date)) {
+			printf(" %s", PRINT_LOCAL_TIME(flags) ? my_tz
+							      : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+											: "UTC"));
 		}
 		printf("; LINUX-RESTART (%d CPU)\n",
 		       file_hdr->sa_cpu_nr > 1 ? file_hdr->sa_cpu_nr - 1 : 1);
@@ -289,13 +272,13 @@ __printf_funct_t print_raw_restart(int *tab, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message (unused here).
  * @cur_time	Time string of current restart message (unused here).
- * @utc		True if @cur_time is expressed in UTC (unused here).
+ * @my_tz	Current timezone (unused here).
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header.
  ***************************************************************************
  */
 __printf_funct_t print_pcp_restart(int *tab, int action, char *cur_date, char *cur_time,
-				   int utc, struct file_header *file_hdr,
+				   char *my_tz, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 #ifdef HAVE_PCP
@@ -335,22 +318,24 @@ __printf_funct_t print_pcp_restart(int *tab, int action, char *cur_date, char *c
  * IN:
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @comment	Comment to display.
  * @sep		Character used as separator.
  * @file_hdr	System activity file standard header.
  ***************************************************************************
  */
-void print_dbppc_comment(char *cur_date, char *cur_time, int utc,
-			 char *comment, char sep, struct file_header *file_hdr)
+void print_dbppc_comment(char *cur_date, char *cur_time, char *my_tz, char *comment,
+			 char sep, struct file_header *file_hdr)
 {
 	printf("%s%c-1%c", file_hdr->sa_nodename, sep, sep);
 	if (strlen(cur_date)) {
 		printf("%s ", cur_date);
 	}
 	printf("%s", cur_time);
-	if (strlen(cur_date) && utc) {
-		printf(" UTC");
+	if (strlen(cur_date)) {
+		printf(" %s", PRINT_LOCAL_TIME(flags) ? my_tz
+						      : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+						                                : "UTC"));
 	}
 	printf("%cCOM %s\n", sep, comment);
 }
@@ -364,20 +349,19 @@ void print_dbppc_comment(char *cur_date, char *cur_time, int utc,
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @comment	Comment to display.
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  ***************************************************************************
  */
 __printf_funct_t print_db_comment(int *tab, int action, char *cur_date, char *cur_time,
-				  int utc, char *comment, struct file_header *file_hdr,
+				  char *my_tz, char *comment, struct file_header *file_hdr,
 				  struct record_header *record_hdr)
 {
 	/* Actions F_BEGIN and F_END ignored */
 	if (action & F_MAIN) {
-		print_dbppc_comment(cur_date, cur_time, utc, comment,
-				    ';', file_hdr);
+		print_dbppc_comment(cur_date, cur_time, my_tz, comment, ';', file_hdr);
 	}
 }
 
@@ -390,20 +374,19 @@ __printf_funct_t print_db_comment(int *tab, int action, char *cur_date, char *cu
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @comment	Comment to display.
  * @file_hdr	System activity file standard header.
  * @record_hdr	Current record header (unused here).
  ***************************************************************************
  */
 __printf_funct_t print_ppc_comment(int *tab, int action, char *cur_date, char *cur_time,
-				   int utc, char *comment, struct file_header *file_hdr,
+				   char *my_tz, char *comment, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 	/* Actions F_BEGIN and F_END ignored */
 	if (action & F_MAIN) {
-		print_dbppc_comment(cur_date, cur_time, utc, comment,
-				    '\t', file_hdr);
+		print_dbppc_comment(cur_date, cur_time, my_tz, comment, '\t', file_hdr);
 	}
 }
 
@@ -416,7 +399,7 @@ __printf_funct_t print_ppc_comment(int *tab, int action, char *cur_date, char *c
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @comment	Comment to display.
  * @file_hdr	System activity file standard header (unused here).
  * @record_hdr	Current record header (unused here).
@@ -426,15 +409,19 @@ __printf_funct_t print_ppc_comment(int *tab, int action, char *cur_date, char *c
  ***************************************************************************
  */
 __printf_funct_t print_xml_comment(int *tab, int action, char *cur_date, char *cur_time,
-				   int utc, char *comment, struct file_header *file_hdr,
+				   char *my_tz, char *comment, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 	if (action & F_BEGIN) {
 		xprintf((*tab)++, "<comments>");
 	}
 	if (action & F_MAIN) {
-		xprintf(*tab, "<comment date=\"%s\" time=\"%s\" utc=\"%d\" com=\"%s\"/>",
-			cur_date, cur_time, utc ? 1 : 0, comment);
+		xprintf(*tab, "<comment date=\"%s\" time=\"%s\" tz=\"%s\" com=\"%s\"/>",
+			cur_date, cur_time,
+			PRINT_LOCAL_TIME(flags) ? my_tz
+						: (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									  : "UTC"),
+			comment);
 	}
 	if (action & F_END) {
 		xprintf(--(*tab), "</comments>");
@@ -450,7 +437,7 @@ __printf_funct_t print_xml_comment(int *tab, int action, char *cur_date, char *c
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @comment	Comment to display.
  * @file_hdr	System activity file standard header (unused here).
  * @record_hdr	Current record header (unused here).
@@ -460,7 +447,7 @@ __printf_funct_t print_xml_comment(int *tab, int action, char *cur_date, char *c
  ***************************************************************************
  */
 __printf_funct_t print_json_comment(int *tab, int action, char *cur_date, char *cur_time,
-				    int utc, char *comment, struct file_header *file_hdr,
+				    char *my_tz, char *comment, struct file_header *file_hdr,
 				    struct record_header *record_hdr)
 {
 	static int sep = FALSE;
@@ -476,8 +463,12 @@ __printf_funct_t print_json_comment(int *tab, int action, char *cur_date, char *
 		xprintf((*tab)++, "{");
 		xprintf(*tab,
 			"\"comment\": {\"date\": \"%s\", \"time\": \"%s\", "
-			"\"utc\": %d, \"com\": \"%s\"}",
-			cur_date, cur_time, utc ? 1 : 0, comment);
+			"\"tz\": \"%s\", \"com\": \"%s\"}",
+			cur_date, cur_time,
+			PRINT_LOCAL_TIME(flags) ? my_tz
+						: (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									  : "UTC"),
+			comment);
 		xprintf0(--(*tab), "}");
 		sep = TRUE;
 	}
@@ -499,21 +490,24 @@ __printf_funct_t print_json_comment(int *tab, int action, char *cur_date, char *
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message.
  * @cur_time	Time string of current restart message.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @comment	Comment to display.
  * @file_hdr	System activity file standard header (unused here).
  * @record_hdr	Current record header (unused here).
  ***************************************************************************
  */
 __printf_funct_t print_raw_comment(int *tab, int action, char *cur_date, char *cur_time,
-				   int utc, char *comment, struct file_header *file_hdr,
+				   char *my_tz, char *comment, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 	/* Actions F_BEGIN and F_END ignored */
 	if (action & F_MAIN) {
 		printf("%s", cur_time);
-		if (strlen(cur_date) && utc) {
-			printf(" UTC");
+		if (strlen(cur_date)) {
+			printf(" %s",
+			       PRINT_LOCAL_TIME(flags) ? my_tz
+						       : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+										 : "UTC"));
 		}
 		printf("; COM %s\n", comment);
 	}
@@ -528,14 +522,14 @@ __printf_funct_t print_raw_comment(int *tab, int action, char *cur_date, char *c
  * @action	Action expected from current function.
  * @cur_date	Date string of current restart message (unused here).
  * @cur_time	Time string of current restart message (unused here).
- * @utc		True if @cur_time is expressed in UTC (unused here).
+ * @my_tz	Current timezone (unused here).
  * @comment	Comment to display.
  * @file_hdr	System activity file standard header (unused here).
  * @record_hdr	Current record header.
  ***************************************************************************
  */
 __printf_funct_t print_pcp_comment(int *tab, int action, char *cur_date, char *cur_time,
-				   int utc, char *comment, struct file_header *file_hdr,
+				   char *my_tz, char *comment, struct file_header *file_hdr,
 				   struct record_header *record_hdr)
 {
 #ifdef HAVE_PCP
@@ -815,7 +809,7 @@ __printf_funct_t print_pcp_statistics(int *tab, int action, struct activity *act
  * @file_hdr	System activity file standard header.
  * @cur_date	Date string of current record.
  * @cur_time	Time string of current record.
- * @utc		True if @cur_time is expressed in UTC.
+ * @my_tz	Current timezone.
  * @itv		Interval of time with preceding record.
  *
  * RETURNS:
@@ -823,7 +817,7 @@ __printf_funct_t print_pcp_statistics(int *tab, int action, struct activity *act
  ***************************************************************************
  */
 char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_date,
-			    char *cur_time, int utc, unsigned long long itv)
+			    char *cur_time, char *my_tz, unsigned long long itv)
 {
 	int isdb = (fmt == F_DB_OUTPUT);
 	static char pre[512];
@@ -838,8 +832,11 @@ char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_dat
 	else {
 		strcpy(temp2, temp1);
 	}
-	snprintf(pre, sizeof(pre), "%s%s%s", temp2, cur_time,
-		 strlen(cur_date) && utc ? " UTC" : "");
+	snprintf(pre, sizeof(pre), "%s%s %s", temp2, cur_time,
+		 strlen(cur_date) ? (PRINT_LOCAL_TIME(flags) ? my_tz
+							     : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+										       : "UTC"))
+				  : "");
 	pre[sizeof(pre) - 1] = '\0';
 
 	if (DISPLAY_HORIZONTALLY(flags)) {
@@ -858,6 +855,7 @@ char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_dat
  * @action	Action expected from current function.
  * @cur_date	Date string of current record.
  * @cur_time	Time string of current record.
+ * @my_tz	Current timezone.
  * @itv		Interval of time with preceding record.
  * @record_hdr	Record header for current sample (unused here).
  * @file_hdr	System activity file standard header.
@@ -868,14 +866,13 @@ char *print_dbppc_timestamp(int fmt, struct file_header *file_hdr, char *cur_dat
  ***************************************************************************
  */
 __tm_funct_t print_ppc_timestamp(void *parm, int action, char *cur_date,
-				 char *cur_time, unsigned long long itv,
+				 char *cur_time, char * my_tz, unsigned long long itv,
 				 struct record_header *record_hdr,
 				 struct file_header *file_hdr, unsigned int flags)
 {
-	int utc = !PRINT_LOCAL_TIME(flags) && !PRINT_TRUE_TIME(flags);
-
 	if (action & F_BEGIN) {
-		return print_dbppc_timestamp(F_PPC_OUTPUT, file_hdr, cur_date, cur_time, utc, itv);
+		return print_dbppc_timestamp(F_PPC_OUTPUT, file_hdr, cur_date, cur_time,
+					     my_tz, itv);
 	}
 
 	return NULL;
@@ -890,6 +887,7 @@ __tm_funct_t print_ppc_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current record.
  * @cur_time	Time string of current record.
+ * @my_tz	Current timezone.
  * @itv		Interval of time with preceding record.
  * @record_hdr	Record header for current sample (unused here).
  * @file_hdr	System activity file standard header.
@@ -900,14 +898,13 @@ __tm_funct_t print_ppc_timestamp(void *parm, int action, char *cur_date,
  ***************************************************************************
  */
 __tm_funct_t print_db_timestamp(void *parm, int action, char *cur_date,
-				char *cur_time, unsigned long long itv,
+				char *cur_time, char *my_tz, unsigned long long itv,
 				struct record_header *record_hdr,
 				struct file_header *file_hdr, unsigned int flags)
 {
-	int utc = !PRINT_LOCAL_TIME(flags) && !PRINT_TRUE_TIME(flags);
-
 	if (action & F_BEGIN) {
-		return print_dbppc_timestamp(F_DB_OUTPUT, file_hdr, cur_date, cur_time, utc, itv);
+		return print_dbppc_timestamp(F_DB_OUTPUT, file_hdr, cur_date, cur_time,
+					     my_tz, itv);
 	}
 	if (action & F_END) {
 		if (DISPLAY_HORIZONTALLY(flags)) {
@@ -927,6 +924,7 @@ __tm_funct_t print_db_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
+ * @my_tz	Current timezone.
  * @itv		Interval of time with preceding record.
  * @record_hdr	Record header for current sample (unused here).
  * @file_hdr	System activity file standard header (unused here).
@@ -934,16 +932,19 @@ __tm_funct_t print_db_timestamp(void *parm, int action, char *cur_date,
  ***************************************************************************
  */
 __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
-				 char *cur_time, unsigned long long itv,
+				 char *cur_time, char *my_tz, unsigned long long itv,
 				 struct record_header *record_hdr,
 				 struct file_header *file_hdr, unsigned int flags)
 {
-	int utc = !PRINT_LOCAL_TIME(flags) && !PRINT_TRUE_TIME(flags);
 	int *tab = (int *) parm;
 
 	if (action & F_BEGIN) {
-		xprintf((*tab)++, "<timestamp date=\"%s\" time=\"%s\" utc=\"%d\" interval=\"%llu\">",
-			cur_date, cur_time, utc ? 1 : 0, itv);
+		xprintf((*tab)++, "<timestamp date=\"%s\" time=\"%s\" tz=\"%s\" interval=\"%llu\">",
+			cur_date, cur_time,
+			PRINT_LOCAL_TIME(flags) ? my_tz
+						: (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									  : "UTC"),
+			itv);
 	}
 	if (action & F_END) {
 		xprintf(--(*tab), "</timestamp>");
@@ -961,6 +962,7 @@ __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current comment.
  * @cur_time	Time string of current comment.
+ * @my_tz	Current timezone.
  * @itv		Interval of time with preceding record.
  * @record_hdr	Record header for current sample (unused here).
  * @file_hdr	System activity file standard header (unused here).
@@ -968,18 +970,21 @@ __tm_funct_t print_xml_timestamp(void *parm, int action, char *cur_date,
  ***************************************************************************
  */
 __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
-				  char *cur_time, unsigned long long itv,
+				  char *cur_time, char *my_tz, unsigned long long itv,
 				  struct record_header *record_hdr,
 				  struct file_header *file_hdr, unsigned int flags)
 {
-	int utc = !PRINT_LOCAL_TIME(flags) && !PRINT_TRUE_TIME(flags);
 	int *tab = (int *) parm;
 
 	if (action & F_BEGIN) {
 		xprintf0(*tab,
 			 "\"timestamp\": {\"date\": \"%s\", \"time\": \"%s\", "
-			 "\"utc\": %d, \"interval\": %llu}",
-			 cur_date, cur_time, utc ? 1 : 0, itv);
+			 "\"tz\": \"%s\", \"interval\": %llu}",
+			 cur_date, cur_time,
+			 PRINT_LOCAL_TIME(flags) ? my_tz
+						 : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+									   : "UTC"),
+			itv);
 	}
 	if (action & F_MAIN) {
 		printf(",\n");
@@ -1000,6 +1005,7 @@ __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current record.
  * @cur_time	Time string of current record.
+ * @my_tz	Current timezone.
  * @itv		Interval of time with preceding record (unused here).
  * @record_hdr	Record header for current sample (unused here).
  * @file_hdr	System activity file standard header (unused here).
@@ -1010,15 +1016,18 @@ __tm_funct_t print_json_timestamp(void *parm, int action, char *cur_date,
  ***************************************************************************
  */
 __tm_funct_t print_raw_timestamp(void *parm, int action, char *cur_date,
-				 char *cur_time, unsigned long long itv,
+				 char *cur_time, char *my_tz, unsigned long long itv,
 				 struct record_header *record_hdr,
 				 struct file_header *file_hdr, unsigned int flags)
 {
-	int utc = !PRINT_LOCAL_TIME(flags) && !PRINT_TRUE_TIME(flags);
 	static char pre[80];
 
 	if (action & F_BEGIN) {
-		snprintf(pre, sizeof(pre), "%s%s", cur_time, strlen(cur_date) && utc ? " UTC" : "");
+		snprintf(pre, sizeof(pre), "%s %s", cur_time,
+			 strlen(cur_date) ? (PRINT_LOCAL_TIME(flags) ? my_tz
+								     : (PRINT_TRUE_TIME(flags) ? file_hdr->sa_tzname
+											       : "UTC"))
+					  : "");
 		pre[sizeof(pre) - 1] = '\0';
 		return pre;
 	}
@@ -1035,6 +1044,7 @@ __tm_funct_t print_raw_timestamp(void *parm, int action, char *cur_date,
  * @action	Action expected from current function.
  * @cur_date	Date string of current record (unused here).
  * @cur_time	Time string of current record (unused here).
+ * @my_tz	Current timezone (unused here).
  * @itv		Interval of time with preceding record (unused here).
  * @record_hdr	Record header for current sample.
  * @file_hdr	System activity file standard header (unused here).
@@ -1045,7 +1055,7 @@ __tm_funct_t print_raw_timestamp(void *parm, int action, char *cur_date,
  ***************************************************************************
  */
 __tm_funct_t print_pcp_timestamp(void *parm, int action, char *cur_date,
-				 char *cur_time, unsigned long long itv,
+				 char *cur_time, char *my_tz, unsigned long long itv,
 				 struct record_header *record_hdr,
 				 struct file_header *file_hdr, unsigned int flags)
 {
@@ -1064,6 +1074,7 @@ __tm_funct_t print_pcp_timestamp(void *parm, int action, char *cur_date,
  * @parm	Specific parameter. Here: number of tabulations.
  * @action	Action expected from current function.
  * @dfile	Unused here (PCP archive file).
+ * @my_tz	Current timezone (unused here).
  * @file_magic	System activity file magic header.
  * @file_hdr	System activity file standard header.
  * @act		Array of activities (unused here).
@@ -1074,7 +1085,7 @@ __tm_funct_t print_pcp_timestamp(void *parm, int action, char *cur_date,
  * @parm	Number of tabulations.
  ***************************************************************************
  */
-__printf_funct_t print_xml_header(void *parm, int action, char *dfile,
+__printf_funct_t print_xml_header(void *parm, int action, char *dfile, char *my_tz,
 				  struct file_magic *file_magic,
 				  struct file_header *file_hdr,
 				  struct activity *act[], unsigned int id_seq[],
@@ -1134,6 +1145,7 @@ __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
  * @parm	Specific parameter. Here: number of tabulations.
  * @action	Action expected from current function.
  * @dfile	Unused here (PCP archive file).
+ * @my_tz	Current timezone (unused here).
  * @file_magic	System activity file magic header.
  * @file_hdr	System activity file standard header.
  * @act		Array of activities (unused here).
@@ -1144,7 +1156,7 @@ __printf_funct_t print_xml_header(void *parm, int action, char *dfile,
  * @parm	Number of tabulations.
  ***************************************************************************
  */
-__printf_funct_t print_json_header(void *parm, int action, char *dfile,
+__printf_funct_t print_json_header(void *parm, int action, char *dfile, char *my_tz,
 				   struct file_magic *file_magic,
 				   struct file_header *file_hdr,
 				   struct activity *act[], unsigned int id_seq[],
@@ -1196,6 +1208,7 @@ __printf_funct_t print_json_header(void *parm, int action, char *dfile,
  * @parm	Specific parameter (unused here).
  * @action	Action expected from current function.
  * @dfile	Name of system activity data file (unused here).
+ * @my_tz	Current timezone (unused here).
  * @file_magic	System activity file magic header.
  * @file_hdr	System activity file standard header.
  * @act		Array of activities.
@@ -1203,7 +1216,7 @@ __printf_funct_t print_json_header(void *parm, int action, char *dfile,
  * @file_actlst	List of (known or unknown) activities in file.
  ***************************************************************************
  */
-__printf_funct_t print_hdr_header(void *parm, int action, char *dfile,
+__printf_funct_t print_hdr_header(void *parm, int action, char *dfile, char *my_tz,
 				  struct file_magic *file_magic,
 				  struct file_header *file_hdr,
 				  struct activity *act[], unsigned int id_seq[],
@@ -1299,6 +1312,7 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile,
  *		max number of views on a single row (@views_per_row).
  * @action	Action expected from current function.
  * @dfile	Name of system activity data file (unused here).
+ * @my_tz	Current timezone (unused here).
  * @file_magic	System activity file magic header (unused here).
  * @file_hdr	System activity file standard header.
  * @act		Array of activities (unused here).
@@ -1306,7 +1320,7 @@ __printf_funct_t print_hdr_header(void *parm, int action, char *dfile,
  * @file_actlst	List of (known or unknown) activities in file (unused here).
  ***************************************************************************
  */
-__printf_funct_t print_svg_header(void *parm, int action, char *dfile,
+__printf_funct_t print_svg_header(void *parm, int action, char *dfile, char *my_tz,
 				  struct file_magic *file_magic,
 				  struct file_header *file_hdr,
 				  struct activity *act[], unsigned int id_seq[],
@@ -1406,6 +1420,7 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile,
  * @parm	Specific parameter (unused here).
  * @action	Action expected from current function.
  * @dfile	Name of PCP archive file.
+ * @my_tz	Current timezone (unused here).
  * @file_magic	System activity file magic header (unused here).
  * @file_hdr	System activity file standard header (unused here).
  * @act		Array of activities (unused here).
@@ -1413,7 +1428,7 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile,
  * @file_actlst	List of (known or unknown) activities in file (unused here).
  ***************************************************************************
  */
-__printf_funct_t print_pcp_header(void *parm, int action, char *dfile,
+__printf_funct_t print_pcp_header(void *parm, int action, char *dfile, char *my_tz,
 				  struct file_magic *file_magic,
 				  struct file_header *file_hdr,
 				  struct activity *act[], unsigned int id_seq[],
@@ -1421,20 +1436,15 @@ __printf_funct_t print_pcp_header(void *parm, int action, char *dfile,
 {
 #ifdef HAVE_PCP
 	char buf[64];
-	struct tm lrectime;
-	time_t t = file_hdr->sa_ust_time;
+	int rc;
 	unsigned long long utc_sec = file_hdr->sa_ust_time;
 
 	if (action & F_BEGIN) {
 		/* Create new PCP context */
 		pmiStart(dfile, FALSE);
 
-		if (PRINT_LOCAL_TIME(flags)) {
-			pmiSetTimezone(file_hdr->sa_tzname);
-		}
-		else {
-			pmiSetTimezone("UTC");
-		}
+		/* Set timezone */
+		pmiSetTimezone(file_hdr->sa_tzname);
 
 		/* Save hostname */
 		pmiSetHostname(file_hdr->sa_nodename);
@@ -1468,14 +1478,10 @@ __printf_funct_t print_pcp_header(void *parm, int action, char *dfile,
 
 	if (action & F_END) {
 		if (action & F_BEGIN) {
-			/* Only the header data will be written to PCP archive */
-			if (!PRINT_LOCAL_TIME(flags)) {
-				/* Convert a time_t value from local time to UTC */
-				if (gmtime_r(&t, &lrectime)) {
-					utc_sec = mktime(&lrectime);
-				}
+			if ((rc = pmiWrite(utc_sec, 0)) < 0) {
+				fprintf(stderr, "PCP: pmiWrite: %s\n", pmiErrStr(rc));
+				exit(4);
 			}
-			pmiWrite(utc_sec, 0);
 		}
 		pmiEnd();
 	}
